@@ -14,7 +14,7 @@
 #' The user can choose to plot or return a dataframe
 #'
 #' @usage
-#' teamBowlingWicketRunsMatch(match,theTeam,plot=TRUE)
+#' teamBowlingWicketRunsMatch(match,theTeam,opposition,plot=TRUE)
 #'
 #' @param match
 #' The match between the teams
@@ -22,11 +22,14 @@
 #' @param theTeam
 #' Team for which bowling performance is required
 #'
+#' @param opposition
+#' The opposition team
+#'
 #' @param plot
 #' If plot= TRUE the dataframe will be plotted else a data frame will be returned
 #'
 #' @return None or data fame
-#' A data frame with the bowling performance in alll matches against all oppositions
+#' A data frame with the bowling performance in all matches against all oppositions
 #'
 #' @references
 #' \url{http://cricsheet.org/}\cr
@@ -43,8 +46,8 @@
 #' #Get the match details
 #' a <- getMatchDetails("England","Pakistan","2006-09-05",dir="../temp")
 #'
-#' teamBowlingWicketRunsMatch(a,"England",plot=FALSE)
-#' teamBowlingWicketRunsMatch(a,"Pakistan")
+#' teamBowlingWicketRunsMatch(a,"England","Pakistan",plot=FALSE)
+#' teamBowlingWicketRunsMatch(a,"Pakistan","England")
 #' }
 #'
 #' @seealso
@@ -54,7 +57,7 @@
 #'
 #' @export
 #'
-teamBowlingWicketRunsMatch <- function(match,theTeam,plot=TRUE){
+teamBowlingWicketRunsMatch <- function(match,theTeam,opposition, plot=TRUE){
     noBalls=wides=team=runs=bowler=wicketKind=wicketPlayerOut=NULL
     team=bowler=ball=wides=noballs=runsConceded=overs=over=wickets=NULL
     # The performance of bowlers of the team is got when the other side is batting. Hence '!-"
@@ -108,14 +111,18 @@ teamBowlingWicketRunsMatch <- function(match,theTeam,plot=TRUE){
 
     # Plot or ourput data frame
     if(plot == TRUE){
-        plot.title <- paste(theTeam,"Number of wickets vs Runs conceded by bowlers")
-        ggplot(data=l,aes(x=factor(wickets),y=runs,fill=factor(wickets))) +
+        plot.title <- paste(theTeam,"Wicket vs Runs conceded (against",opposition,")")
+
+       p <- ggplot(data=l,aes(x=factor(wickets),y=runs,fill=factor(wickets))) +
             facet_grid(. ~ bowler,scales = "free_x", space = "free_x") +
             geom_bar(stat="identity") +
             xlab("Number of wickets") + ylab("Total runs conceded") +
             ggtitle(bquote(atop(.(plot.title),
                                     atop(italic("Data source:http://cricsheet.org/"),"")))) +
-            theme(axis.text.x = element_text(angle = 90, hjust = 1))
+            theme(axis.text.x = element_text(angle = 90, hjust = 1)) +
+            theme(plot.title = element_text(size=14,margin=margin(10)))
+
+        p
     }
     else {
         l
